Crate crypsol_logger

Crate crypsol_logger 

Modules

http_backend
logs

Macros

log
A macro for logging a message with a given log::Level. If LOG_TO_CLOUDWATCH is “true”, it sends the log to CloudWatch asynchronously. Otherwise, it logs to the console.
log_custom
A macro for logging a message with a custom log stream name. If LOG_TO_CLOUDWATCH is “true”, it sends the log to CloudWatch asynchronously under the specified custom stream. Otherwise, it prints logs to the console.

Enums

Level
An enum representing the available verbosity levels of the logger.